==> open-xchange-usm_7.4.0.orig.tar.bz2: open-xchange-usm-7.4.0/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/sync/FolderElementsStorage.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.session.sync;

import java.util.BitSet;
import com.openexchange.usm.api.contenttypes.OXFolderContent;
import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.OXCommunicationException;
import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.api.exceptions.USMSQLException;
import com.openexchange.usm.api.session.DataObject;
import com.openexchange.usm.api.session.DataObjectFilter;
import com.openexchange.usm.api.session.Folder;
import com.openexchange.usm.api.session.Session;
import com.openexchange.usm.session.dataobject.DataObjectSet;
import com.openexchange.usm.session.impl.SessionImpl;

public class FolderElementsStorage implements ContentSyncerStorage {

    private final SessionImpl _session;

    private final Folder _folder;

    private final DataObjectFilter _filter;

    private final boolean _storeResult;

    private final long _oldTimestamp;

    private final OXDataCacheID _cacheID;

    private final int _limit;

    public FolderElementsStorage(SessionImpl session, Folder folder, DataObjectFilter filter, boolean storeResult, long oldTimestamp, int limit) {
        _session = session;
        _folder = folder;
        _filter = filter;
        _storeResult = storeResult;
        _oldTimestamp = (filter != null && filter.getOriginalSyncID() != 0L) ? filter.getOriginalSyncID() : oldTimestamp;
        _cacheID = new OXDataCacheID(session, _folder.getID());
        _limit = limit;
    }

    public boolean getCurrentServerData(DataObjectSet resultSet) throws USMException {
        try {
            OXFolderContent data = readCurrentFolderContent();
            for (DataObject o : data.getObjects()) {
                o.setParentFolderOwnerID(_folder.getOwnerID());
                o.commitChanges();
                if (_filter == null || _filter.accept(o))
                    resultSet.add(o);
            }
            return data.isComplete();
        } catch (OXCommunicationException e) {
            // Check if folder itself can be read (will throw FolderNotFoundException if not), throw original exception if folder is still
            // accessible
            _folder.getContentType().getTransferHandler().readFolder(_folder, new BitSet());
            throw e;
        }
    }

    private OXFolderContent readCurrentFolderContent() throws USMException {
        if (_limit == Session.NO_LIMIT)
            return new OXFolderContent(true, _folder.getElementsContentType().getTransferHandler().readFolderContent(_folder));
        return _folder.getElementsContentType().getTransferHandler().readFolderContent(_folder, Math.max(_limit, 0) + 10);
    }

    public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws DatabaseAccessException, USMSQLException {
        return _storeResult ? _session.storeCachedDataObjects(_folder.getID(), _oldTimestamp, timestamp, data, updatesPending) : 0L;
    }

    public OXDataCacheID getCacheID() {
        return _cacheID;
    }

    @Override
    public String toString() {
        return String.valueOf(_session) + ' ' + _folder.getID() + '(' + _storeResult + ')';
    }

    public DataObject findMatchingClientObjectForServerObject(DataObjectSet clientDataObjects, DataObject serverObject) {
        return null;
    }
}

==> open-xchange-usm_7.4.2.orig.tar.bz2: open-xchange-usm-7.4.2/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/sync/FolderElementsStorage.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.session.sync;

import java.util.BitSet;
import com.openexchange.usm.api.contenttypes.OXFolderContent;
import com.openexchange.usm.api.database.DatabaseAccessException;
import com.openexchange.usm.api.exceptions.OXCommunicationException;
import com.openexchange.usm.api.exceptions.USMException;
import com.openexchange.usm.api.exceptions.USMSQLException;
import com.openexchange.usm.api.session.DataObject;
import com.openexchange.usm.api.session.DataObjectFilter;
import com.openexchange.usm.api.session.Folder;
import com.openexchange.usm.api.session.Session;
import com.openexchange.usm.session.dataobject.DataObjectSet;
import com.openexchange.usm.session.impl.SessionImpl;

public class FolderElementsStorage implements ContentSyncerStorage {

    private final SessionImpl _session;

    private final Folder _folder;

    private final DataObjectFilter _filter;

    private final boolean _storeResult;

    private final long _oldTimestamp;

    private final OXDataCacheID _cacheID;

    private final int _limit;

    public FolderElementsStorage(SessionImpl session, Folder folder, DataObjectFilter filter, boolean storeResult, long oldTimestamp, int limit) {
        _session = session;
        _folder = folder;
        _filter = filter;
        _storeResult = storeResult;
        _oldTimestamp = (filter != null && filter.getOriginalSyncID() != 0L) ? filter.getOriginalSyncID() : oldTimestamp;
        _cacheID = new OXDataCacheID(session, _folder.getID());
        _limit = limit;
    }

    public boolean getCurrentServerData(DataObjectSet resultSet) throws USMException {
        try {
            OXFolderContent data = readCurrentFolderContent();
            for (DataObject o : data.getObjects()) {
                o.setParentFolderOwnerID(_folder.getOwnerID());
                o.commitChanges();
                if (_filter == null || _filter.accept(o))
                    resultSet.add(o);
            }
            return data.isComplete();
        } catch (OXCommunicationException e) {
            // Check if folder itself can be read (will throw FolderNotFoundException if not), throw original exception if folder is still
            // accessible
            _folder.getContentType().getTransferHandler().readFolder(_folder, new BitSet());
            throw e;
        }
    }

    private OXFolderContent readCurrentFolderContent() throws USMException {
        if (_limit == Session.NO_LIMIT)
            return new OXFolderContent(true, _folder.getElementsContentType().getTransferHandler().readFolderContent(_folder));
        return _folder.getElementsContentType().getTransferHandler().readFolderContent(_folder, Math.max(_limit, 0) + 10, _filter);
    }

    public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws USMException {
        return _storeResult ? _session.storeCachedDataObjects(_folder.getID(), _oldTimestamp, timestamp, data, updatesPending) : 0L;
    }

    public OXDataCacheID getCacheID() {
        return _cacheID;
    }

    @Override
    public String toString() {
        return String.valueOf(_session) + ' ' + _folder.getID() + '(' + _storeResult + ')';
    }

    public DataObject findMatchingClientObjectForServerObject(DataObjectSet clientDataObjects, DataObject serverObject) {
        return null;
    }
}
